devicesinlan_gui - Mariano Muñoz

# NAME

devicesinlan_gui: Scans all devices in your LAN. Then you can set an alias to your known devices in order to detect future strange devices in your net.

# SYNOPSIS

devicesinlan_gui [--help] [--version] [--debug DEBUG]

# DESCRIPTION

In the app menu you have the followings features:

Devices > New Scan

Searches all devices in tha LAN and show them in a new tab. If some device is not in the known devices list it will be shown with a red background. Devices with a green background are trusted devices

Devices > Show devices database

Shows all known devices in a new tab.

Right click allows you to edit known devices database.

Devices > Load devices list

Loads a list of known devices in xml format.

Devices > Save devices list

Saves the known devices list to a xml file.

Devices > Reset database

Removes all known devices.

This option erases all known devices in database.

Configuration > Settings

In this dialog you can select your prefered language and you can configure the number of concurrence request.

Help > Help

Shows this help information.

Help > About

Shows information about DevicesInLAN license and authors.

Help > Check for updates

Checks for updates in DevicesInLan repository.

Help > Exit

Exits from program.

Created with libmangenerator at 2018-11-26